@@ -54,7 +54,9 @@
 #include "config.h"
 
 /* version */
+#define _FSL_VERSION_C_AS_HEADER_
 #include "fsl_version.c"
+#undef  _FSL_VERSION_C_AS_HEADER_
 
 /* pcre static vector size */
 #define OVECSIZE 30
@@ -430,7 +432,6 @@ static fsl_rc_t processcfg(cfg_t *cfg, char *cpISF, int mode)
     l2_result_t       l2rv;
     int               matchcount = 0;
     pcre       *pcreRegex = NULL;
-    pcre_extra *pcreExtra = NULL;
     const char *cpError;
     int         iError;
     int         nMatch;
@@ -526,13 +527,10 @@ static fsl_rc_t processcfg(cfg_t *cfg, char *cpISF, int mode)
                 fsldebug(L2_LEVEL_DEBUG, "processcfg: argident=%s, argmatch=%s, argl2spec=%s", argident, argmatch, argl2spec);
 
                 /* compile regular expression into finite state machine and optimize */
-                if ((pcreRegex = pcre_compile(argmatch, PCRE_CASELESS, &cpError, &iError, NULL)) == NULL) {
+                if ((pcreRegex = pcre_compile(argmatch, PCRE_ANCHORED|PCRE_CASELESS, &cpError, &iError, NULL)) == NULL) {
                     fsldebug(L2_LEVEL_ERROR, "processcfg: pcre_compile() failed with error %s (%d)", cpError, iError); CU(FSL_ERR_CUS); }
-                pcreExtra = pcre_study(pcreRegex, 0, &cpError);
-                if (cpError != NULL) {
-                    fsldebug(L2_LEVEL_ERROR, "processcfg: pcre_study() failed with error %s", cpError); CU(FSL_ERR_CUS); }
 
-                nMatch = pcre_exec(pcreRegex, pcreExtra, cpISF, strlen(cpISF), 0, 0, ovec, OVECSIZE);
+                nMatch = pcre_exec(pcreRegex, NULL, cpISF, strlen(cpISF), 0, 0, ovec, OVECSIZE);
                 if (nMatch < 0)
                     fsldebug(L2_LEVEL_TRACE, "processcfg: matching ident/facility \"%s\" against section \"%s\" failed.", cpISF, argmatch);
                 else
@@ -561,10 +559,6 @@ static fsl_rc_t processcfg(cfg_t *cfg, char *cpISF, int mode)
                     matchcount++;
                     free(argl2spec);
                 }
-                if (pcreExtra != NULL) {
-                    pcre_free(pcreExtra);
-                    pcreExtra = NULL;
-                }
                 if (pcreRegex != NULL) {
                     pcre_free(pcreRegex);
                     pcreRegex = NULL;
@@ -612,10 +606,6 @@ static fsl_rc_t processcfg(cfg_t *cfg, char *cpISF, int mode)
     else
         CU(FSL_OK);
 CUS:
-    if (pcreExtra != NULL) {
-        pcre_free(pcreExtra);
-        pcreExtra = NULL;
-    }
     if (pcreRegex != NULL) {
         pcre_free(pcreRegex);
         pcreRegex = NULL;
@@ -716,7 +706,7 @@ void openlog(const char *ident, int logopt, int facility)
     openfsldebug();
 
     /* tracing */
-    fsldebug(L2_LEVEL_TRACE, "openlog() ident=\"%s\", logopt=0x%.8lx, facility=0x%.8lx; caught by FSL %s", ident, logopt, facility, fsl_version.v_gnu);
+    fsldebug(L2_LEVEL_TRACE, "openlog() ident=\"%s\", logopt=0x%.8lx, facility=0x%.8lx; caught by %s", ident, logopt, facility, fsl_version.v_gnu);
 
     /* remember logopt and handle unsupported values */
     ctx.logopt = logopt;
