@@ -5,7 +5,7 @@
 int main(int argc, char *argv[])
 {
     syslog(LOG_INFO, "Connection from host %s", "foo.bar.dom");
-    openlog("mail", LOG_PID|LOG_NDELAY, LOG_FTP);
+    openlog("mail", LOG_PID|LOG_NDELAY, LOG_LOCAL0);
     syslog(LOG_ALERT, "who: internal error 23\n");
     setlogmask(LOG_UPTO(LOG_ERR));
     syslog(LOG_INFO|LOG_LOCAL2, "foobar error: %m");
