@@ -443,8 +443,9 @@ cfg_node_select_step2(
         fprintf(stderr, "step2: child node 0x%lx\n", (unsigned long)node);
         do {
             if (node->token != NULL) {
+                size_t l;
                 token = node->token;
-                size_t l = strlen(token);
+                l = strlen(token);
                 fprintf(stderr, "step2: child node: \"%s\"\n", token);
                 if (   (l == 1 && l == nSel && token[0] == '*')
                     || (l == nSel && strncmp(token, cpSel, nSel) == 0)) {
